=======
abelian
=======

.. image:: https://readthedocs.org/projects/abelian/badge/?version=latest
    :target: http://abelian.readthedocs.io/en/latest/?badge=latest
    :alt: Documentation Status

``abelian`` is a Python library for computations on locally compact Abelian groups.
Please see `the documentation <http://abelian.readthedocs.io/en/latest/>`_ for more information.

Project Goals
==============

* Classical groups R, T, Z and Z_n and computations on these.
* Relationship between continuous and discrete should be 'pretty'.
* FFT computations on discrete, compact groups (and their products).
* The software should build on the mathematical theory.


Todo
============

* Create skeleton for project
* Factorizations of homomorphisms between FGAs (tests, docs, implementation)
